@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/)
 
 Usage::
 
@@ -61,7 +61,7 @@ class Exceptions:
 class EBSClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/)
     """
 
     meta: ClientMeta
@@ -72,7 +72,7 @@ class EBSClient(BaseClient):
         EBSClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -80,7 +80,7 @@ class EBSClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#can_paginate)
         """
 
     def complete_snapshot(
@@ -97,7 +97,7 @@ class EBSClient(BaseClient):
         been written to it.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.complete_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#complete_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#complete_snapshot)
         """
 
     def generate_presigned_url(
@@ -111,7 +111,7 @@ class EBSClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#generate_presigned_url)
         """
 
     def get_snapshot_block(
@@ -121,7 +121,7 @@ class EBSClient(BaseClient):
         Returns the data in a block in an Amazon Elastic Block Store snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.get_snapshot_block)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#get_snapshot_block)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#get_snapshot_block)
         """
 
     def list_changed_blocks(
@@ -138,7 +138,7 @@ class EBSClient(BaseClient):
         Elastic Block Store snapshots of the same volume/snapshot lineage.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.list_changed_blocks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#list_changed_blocks)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#list_changed_blocks)
         """
 
     def list_snapshot_blocks(
@@ -153,7 +153,7 @@ class EBSClient(BaseClient):
         Returns information about the blocks in an Amazon Elastic Block Store snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#list_snapshot_blocks)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#list_snapshot_blocks)
         """
 
     def put_snapshot_block(
@@ -161,7 +161,7 @@ class EBSClient(BaseClient):
         *,
         SnapshotId: str,
         BlockIndex: int,
-        BlockData: Union[bytes, IO[bytes], StreamingBody],
+        BlockData: Union[str, bytes, IO[Any], StreamingBody],
         DataLength: int,
         Checksum: str,
         ChecksumAlgorithm: Literal["SHA256"],
@@ -171,7 +171,7 @@ class EBSClient(BaseClient):
         Writes a block of data to a snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.put_snapshot_block)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#put_snapshot_block)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#put_snapshot_block)
         """
 
     def start_snapshot(
@@ -179,7 +179,7 @@ class EBSClient(BaseClient):
         *,
         VolumeSize: int,
         ParentSnapshotId: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         Description: str = ...,
         ClientToken: str = ...,
         Encrypted: bool = ...,
@@ -190,5 +190,5 @@ class EBSClient(BaseClient):
         Creates a new Amazon EBS snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#EBS.Client.start_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#start_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ebs/client/#start_snapshot)
         """
